@@ -53,6 +53,7 @@ static gboolean gnumeric_no_warnings = FALSE;
 static gchar  *func_def_file = NULL;
 static gchar  *func_state_file = NULL;
 static gchar  *ext_refs_file = NULL;
+static gchar  *samples_file = NULL;
 static gchar  *geometry = NULL;
 static gchar **startup_files;
 
@@ -90,6 +91,12 @@ static const GOptionEntry gnumeric_options [] = {
 		N_("Dumps web page for function help"),
 		N_("FILE")
 	},
+	{
+		"samples-file", 0,
+		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &samples_file,
+		N_("Dumps list of samples in function help"),
+		N_("FILE")
+	},
 	{
 		"split-func", 0,
 		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &split_funcdocs,
@@ -287,6 +294,8 @@ main (int argc, char const **argv)
 		return gnm_dump_func_defs (NULL, 2);
 	if (ext_refs_file)
 		return gnm_dump_func_defs (ext_refs_file, 4);
+	if (samples_file)
+		return gnm_dump_func_defs (samples_file, 5);
 
 	if (with_gui) {
 		go_component_set_default_command_context (cc = gnm_cmd_context_stderr_new ());
