@@ -58,6 +58,9 @@ void          gnm_style_cond_set_expr (GnmStyleCond *cond,
 				       GnmExprTop const *texpr,
 				       unsigned idx);
 
+GnmExprTop const *gnm_style_cond_get_alternate_expr (GnmStyleCond const *cond);
+void gnm_style_cond_canonicalize (GnmStyleCond *cond);
+
 Sheet      *gnm_style_cond_get_sheet (GnmStyleCond const *cond);
 void        gnm_style_cond_set_sheet (GnmStyleCond *cond, Sheet *sheet);
 
@@ -81,6 +84,9 @@ void        gnm_style_conditions_set_sheet (GnmStyleConditions *sc,
 
 guint32     gnm_style_conditions_hash      (GnmStyleConditions const *sc);
 
+gboolean    gnm_style_conditions_equal     (GnmStyleConditions const *sca,
+					    GnmStyleConditions const *scb);
+
 G_END_DECLS
 
 #endif /* _GNM_STYLE_CONDITIONS_H_ */
